@@ -43,7 +43,7 @@ class Model(object):
 		db.query('delete from %s where id = %%s' % self._table, id)
 		mc.delete('%s:%s' % (self._table, id))
 
-def _getattr__(self, name):
+def _getattr(self, name):
 	self.query('select 1 from %s' % name)
 	return Model(name, self, mc)
 
